Author: breser
Date: Fri Dec 14 05:52:37 2012
New Revision: 1421676

URL: http://svn.apache.org/viewvc?rev=1421676&view=rev
Log:
Remove some neon references still lingering about.

* get-deps.sh
  (get_deps): No reason to warn that we won't be downloading neon if the neon
    directory exists, since we won't be downloading neon anyway.

* build/win32
  (svn:ignore): build_neon.bat shouldn't be being produced.  Let people realize
    they can delete this obsolete file.

* subversion/bindings/swig/python/tests/ra.py
  (test_namestring): ra_neon is gone and ra_svn supports get_client_string so
    allow the test to run against svn:// and make the comment accurate.

* subversion/bindings/swig/perl/native/Core.pm
  (SVN::Auth::SSL::OTHER): Update documentation to not refer to a specific
    http lib.

* subversion/bindings/swig/perl/native/Makefile.PL.in
  (@ldpaths): Don't include libsvn_ra_neon in the library paths.

* aclocal.m4: Don't include the neon.m4 file.


Modified:
    subversion/trunk/aclocal.m4
    subversion/trunk/build/win32/   (props changed)
    subversion/trunk/get-deps.sh
    subversion/trunk/subversion/bindings/swig/perl/native/Core.pm
    subversion/trunk/subversion/bindings/swig/perl/native/Makefile.PL.in
    subversion/trunk/subversion/bindings/swig/python/tests/ra.py

Modified: subversion/trunk/aclocal.m4
URL: 
http://svn.apache.org/viewvc/subversion/trunk/aclocal.m4?rev=1421676&r1=1421675&r2=1421676&view=diff
==============================================================================
--- subversion/trunk/aclocal.m4 (original)
+++ subversion/trunk/aclocal.m4 Fri Dec 14 05:52:37 2012
@@ -39,7 +39,6 @@ sinclude(build/ac-macros/berkeley-db.m4)
 sinclude(build/ac-macros/ctypesgen.m4)
 sinclude(build/ac-macros/gssapi.m4)
 sinclude(build/ac-macros/java.m4)
-sinclude(build/ac-macros/neon.m4)
 sinclude(build/ac-macros/sasl.m4)
 sinclude(build/ac-macros/serf.m4)
 sinclude(build/ac-macros/sqlite.m4)

Propchange: subversion/trunk/build/win32/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Fri Dec 14 05:52:37 2012
@@ -1,5 +1,4 @@
 build_locale.bat
-build_neon.bat
 build_zlib.bat
 make_dist.conf
 make_dist.log

Modified: subversion/trunk/get-deps.sh
URL: 
http://svn.apache.org/viewvc/subversion/trunk/get-deps.sh?rev=1421676&r1=1421675&r2=1421676&view=diff
==============================================================================
--- subversion/trunk/get-deps.sh (original)
+++ subversion/trunk/get-deps.sh Fri Dec 14 05:52:37 2012
@@ -107,7 +107,7 @@ get_sqlite() {
 get_deps() {
     mkdir -p $TEMPDIR
 
-    for i in neon zlib serf sqlite-amalgamation apr apr-util; do
+    for i in zlib serf sqlite-amalgamation apr apr-util; do
       if [ -d $i ]; then
         echo "Local directory '$i' already exists; the downloaded copy won't 
be used" >&2
       fi

Modified: subversion/trunk/subversion/bindings/swig/perl/native/Core.pm
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/bindings/swig/perl/native/Core.pm?rev=1421676&r1=1421675&r2=1421676&view=diff
==============================================================================
--- subversion/trunk/subversion/bindings/swig/perl/native/Core.pm (original)
+++ subversion/trunk/subversion/bindings/swig/perl/native/Core.pm Fri Dec 14 
05:52:37 2012
@@ -1012,8 +1012,7 @@ Certificate authority is unknown (i.e. n
 
 =item $SVN::Auth::SSL::OTHER
 
-Other failure. This can happen if neon has introduced a new failure bit that we
-do not handle yet.
+Other failure. This can happen if some unknown error condition occurs.
 
 =back
 

Modified: subversion/trunk/subversion/bindings/swig/perl/native/Makefile.PL.in
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/bindings/swig/perl/native/Makefile.PL.in?rev=1421676&r1=1421675&r2=1421676&view=diff
==============================================================================
--- subversion/trunk/subversion/bindings/swig/perl/native/Makefile.PL.in 
(original)
+++ subversion/trunk/subversion/bindings/swig/perl/native/Makefile.PL.in Fri 
Dec 14 05:52:37 2012
@@ -39,8 +39,8 @@ my $swig_builddir = "${svnlib_builddir}/
 my @modules = qw/client delta fs ra repos wc/;
 my @ldpaths = (abs_path($swig_builddir) . "/perl/libsvn_swig_perl/.libs",
                map { abs_path($svnlib_builddir) . "/libsvn_$_/.libs" }
-                   @modules, qw/diff subr ra_local ra_svn ra_neon
-                                ra_serf fs_base fs_util fs_fs/);
+                   @modules, qw/diff subr ra_local ra_svn ra_serf
+                                fs_base fs_util fs_fs/);
 
 my @ldmodules = map {"-lsvn_$_-1"} (@modules, qw/diff subr/);
 

Modified: subversion/trunk/subversion/bindings/swig/python/tests/ra.py
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/bindings/swig/python/tests/ra.py?rev=1421676&r1=1421675&r2=1421676&view=diff
==============================================================================
--- subversion/trunk/subversion/bindings/swig/python/tests/ra.py (original)
+++ subversion/trunk/subversion/bindings/swig/python/tests/ra.py Fri Dec 14 
05:52:37 2012
@@ -375,8 +375,9 @@ class SubversionRepositoryAccessTestCase
     reporter.finish_report(reporter_baton)
 
   def test_namestring(self):
-    # Only ra-{neon,serf} support this right now.
-    if self.repos_uri.startswith('http'):
+    # Only ra-{svn,serf} support this right now.
+    uri = self.repos_uri
+    if uri.startswith('http') or uri.startswith('svn'):
       called = [False]
       def cb(pool):
         called[0] = True


Reply via email to